==> client-sdk-react-0.59.0.tgz: package/src/components/Chat/ChatInput/CustomizableChatInput.tsx <==
import React, { useEffect, useRef, useState } from 'react'
import { ChatInputElementProps, CustomizableChatInputProps } from '../models'
import { ChatMessageInput } from './ChatMessageInput'
import { RecipientSelector } from './RecipientSelector'
import { EmojiSelector } from './EmojiSelector'
import { SendButton } from './SendButton'
import { AttachmentDisplay, AttachmentUploader } from './Attachment'
import { ChatAttachmentModel } from '../../../store/chat/models'
import './CustomizableChatInput.scss'

export const CustomizableChatInput: React.FC<ChatInputElementProps & CustomizableChatInputProps> = ({
  remoteParticipants,
  sendPublicMessage,
  sendPrivateMessage,
  uploadAttachment,
  chatMessageInputElement,
  sendButtonElement,
  recipientSelectorElement,
  emojiSelectorElement,
  attachmentUploaderElement,
  attachmentDisplayElement,
}) => {
  const [currentMessage, setCurrentMessage] = useState('')
  const [messageRecipient, setMessageRecipient] = useState('')
  const [attachment, setAttachment] = useState<ChatAttachmentModel>()
  const [isUploading, setUploading] = useState(false)
  const [hasAttachmentError, setAttachmentError] = useState(false)
  const chatMessageInputRef = useRef<HTMLElement>(null)

  const recipientParticipant = remoteParticipants?.find((p) => p.id === messageRecipient)

  const sendMessage = () => {
    const messageToSend = currentMessage.trim()
    if (!messageToSend && !attachment) {
      return
    }
    if (!messageRecipient) {
      sendPublicMessage && sendPublicMessage(messageToSend, attachment)
    }
    if (recipientParticipant) {
      sendPrivateMessage && sendPrivateMessage(messageToSend, recipientParticipant, attachment)
    }
    setCurrentMessage('')
    clearAttachment()
  }

  const recipientSelectedHandler = (recipientId: string) => {
    setAttachment(undefined)
    setMessageRecipient(recipientId)
  }

  const emojiSelectedHandler = (emoji: string) => {
    if (!currentMessage) {
      setCurrentMessage(emoji)
    } else {
      setCurrentMessage((currentMessage) => `${currentMessage} ${emoji}`)
    }
    chatMessageInputRef.current?.focus()
  }

  const attachmentUploadStartedHandler = () => {
    setUploading(true)
    setAttachmentError(false)
  }

  const attachmentUploadFinishedHandler = (file: File, fileId: string) => {
    setAttachment({ fileId, fileName: file.name, fileSize: file.size, contentType: file.type })
    setUploading(false)
    chatMessageInputRef.current?.focus()
  }

  const attachmentUploadFailedHandler = () => {
    clearAttachment()
    setUploading(false)
    setAttachmentError(true)
  }

  const clearAttachment = () => {
    setAttachment(undefined)
  }

  useEffect(() => {
    if (messageRecipient && remoteParticipants && !remoteParticipants.some((p) => p.id === messageRecipient)) {
      setMessageRecipient('')
      setCurrentMessage('')
    }
  }, [messageRecipient, remoteParticipants])

  const ChatMessageInputElement = chatMessageInputElement ?? ChatMessageInput
  const RecipientSelectorElement = recipientSelectorElement ?? RecipientSelector
  const EmojiSelectorElement = emojiSelectorElement ?? EmojiSelector
  const SendButtonElement = sendButtonElement ?? SendButton
  const AttachmentUploaderElement = attachmentUploaderElement ?? AttachmentUploader
  const AttachmentDisplayElement = attachmentDisplayElement ?? AttachmentDisplay

  return (
    <div className='chat-input__input-group'>
      <div className='chat-input__message-input-container'>
        <div className='chat-input__top-bar'>
          <RecipientSelectorElement
            remoteParticipants={remoteParticipants}
            onRecipientSelected={recipientSelectedHandler}
          />
          <EmojiSelectorElement onSelectEmoji={emojiSelectedHandler} currentMessage={currentMessage} />
          {uploadAttachment && (
            <AttachmentUploaderElement
              uploadAttachment={uploadAttachment}
              attachmentRecipient={recipientParticipant}
              onAttachmentUploadStarted={attachmentUploadStartedHandler}
              onAttachmentUploadFinished={attachmentUploadFinishedHandler}
              onAttachmentUploadFailed={attachmentUploadFailedHandler}
            />
          )}
        </div>
        <ChatMessageInputElement
          ref={chatMessageInputRef}
          currentChatMessage={currentMessage}
          onChatMessageChanged={(message) => setCurrentMessage(message)}
          sendMessage={sendMessage}
        />
        <AttachmentDisplayElement
          attachment={attachment}
          onClearAttachment={clearAttachment}
          hasAttachmentError={hasAttachmentError}
        />
      </div>
      <SendButtonElement disabled={!currentMessage.trim() && !attachment} onClick={sendMessage} />
      {isUploading && (
        <div className='chat-input__loader-container'>
          <div className='chat-input__loader' />
        </div>
      )}
    </div>
  )
}

==> client-sdk-react-1.0.0.tgz: package/src/components/Chat/ChatInput/CustomizableChatInput.tsx <==
import React, { useEffect, useRef, useState } from 'react'
import { ChatInputElementProps, CustomizableChatInputProps } from '../models'
import { AttachmentDisplay, AttachmentUploader } from './Attachment'
import { ChatAttachmentModel } from '../../../store/chat/models'
import { ChatMessageInput } from './ChatMessageInput'
import { RecipientSelector } from './RecipientSelector'
import { EmojiSelector } from './EmojiSelector'
import { SendButton } from './SendButton'
import './CustomizableChatInput.scss'

export const CustomizableChatInput: React.FC<ChatInputElementProps & CustomizableChatInputProps> = ({
  messageRecipient,
  onRecipientSelected,
  remoteParticipants,
  sendPublicMessage,
  sendPrivateMessage,
  uploadAttachment,
  chatMessageInputElement,
  sendButtonElement,
  recipientSelectorElement,
  emojiSelectorElement,
  attachmentUploaderElement,
  attachmentDisplayElement,
}) => {
  const [currentMessage, setCurrentMessage] = useState('')
  const [attachment, setAttachment] = useState<ChatAttachmentModel>()
  const [isUploading, setUploading] = useState(false)
  const [hasAttachmentError, setAttachmentError] = useState(false)
  const chatMessageInputRef = useRef<HTMLElement>(null)

  const recipientParticipant = remoteParticipants?.find((p) => p.id === messageRecipient)

  const sendMessage = () => {
    const messageToSend = currentMessage.trim()
    if (!messageToSend && !attachment) {
      return
    }
    if (!messageRecipient) {
      sendPublicMessage && sendPublicMessage(messageToSend, attachment)
    }
    if (recipientParticipant) {
      sendPrivateMessage && sendPrivateMessage(messageToSend, recipientParticipant, attachment)
    }
    setCurrentMessage('')
    clearAttachment()
  }

  const recipientSelectedHandler = (recipientId: string) => {
    setAttachment(undefined)
    onRecipientSelected && onRecipientSelected(recipientId)
  }

  const emojiSelectedHandler = (emoji: string) => {
    if (!currentMessage) {
      setCurrentMessage(emoji)
    } else {
      setCurrentMessage((currentMessage) => `${currentMessage} ${emoji}`)
    }
    chatMessageInputRef.current?.focus()
  }

  const attachmentUploadStartedHandler = () => {
    setUploading(true)
    setAttachmentError(false)
  }

  const attachmentUploadFinishedHandler = (file: File, fileId: string) => {
    setAttachment({ fileId, fileName: file.name, fileSize: file.size, contentType: file.type })
    setUploading(false)
    chatMessageInputRef.current?.focus()
  }

  const attachmentUploadFailedHandler = () => {
    clearAttachment()
    setUploading(false)
    setAttachmentError(true)
  }

  const clearAttachment = () => {
    setAttachment(undefined)
  }

  useEffect(() => {
    if (messageRecipient && remoteParticipants && !remoteParticipants.some((p) => p.id === messageRecipient)) {
      onRecipientSelected && onRecipientSelected('')
      setCurrentMessage('')
    }
  }, [onRecipientSelected, messageRecipient, remoteParticipants])

  const ChatMessageInputElement = chatMessageInputElement ?? ChatMessageInput
  const RecipientSelectorElement = recipientSelectorElement ?? RecipientSelector
  const EmojiSelectorElement = emojiSelectorElement ?? EmojiSelector
  const SendButtonElement = sendButtonElement ?? SendButton
  const AttachmentUploaderElement = attachmentUploaderElement ?? AttachmentUploader
  const AttachmentDisplayElement = attachmentDisplayElement ?? AttachmentDisplay

  return (
    <div className='chat-input__input-group'>
      <div className='chat-input__message-input-container'>
        <div className='chat-input__top-bar'>
          <RecipientSelectorElement
            remoteParticipants={remoteParticipants}
            onRecipientSelected={recipientSelectedHandler}
          />
          <EmojiSelectorElement onSelectEmoji={emojiSelectedHandler} currentMessage={currentMessage} />
          {uploadAttachment && (
            <AttachmentUploaderElement
              uploadAttachment={uploadAttachment}
              attachmentRecipient={recipientParticipant}
              onAttachmentUploadStarted={attachmentUploadStartedHandler}
              onAttachmentUploadFinished={attachmentUploadFinishedHandler}
              onAttachmentUploadFailed={attachmentUploadFailedHandler}
            />
          )}
        </div>
        <ChatMessageInputElement
          ref={chatMessageInputRef}
          currentChatMessage={currentMessage}
          onChatMessageChanged={(message) => setCurrentMessage(message)}
          sendMessage={sendMessage}
        />
        <AttachmentDisplayElement
          attachment={attachment}
          onClearAttachment={clearAttachment}
          hasAttachmentError={hasAttachmentError}
        />
      </div>
      <SendButtonElement disabled={!currentMessage.trim() && !attachment} onClick={sendMessage} />
      {isUploading && (
        <div className='chat-input__loader-container'>
          <div className='chat-input__loader' />
        </div>
      )}
    </div>
  )
}
